# blurhash-py

[![PyPI - Version](https://img.shields.io/pypi/v/blurhash-py)](https://pypi.org/project/blurhash-py/)

A Python and rust library for encoding and decoding blurhash strings where most of the code is
ported from the original [blurhash](https://github.com/woltapp/blurhash) library.

## Installation

```bash
pip install blurhash-py
```
